summaryrefslogtreecommitdiffstats
path: root/bin/g-i-installation.sh
diff options
context:
space:
mode:
authorHelmut Grohne <helmut@subdivi.de>2015-02-10 19:48:45 +0100
committerHolger Levsen <holger@layer-acht.org>2015-02-11 13:34:17 +0100
commit28aad1febdd67f72a2655a58348e7f768574da4f (patch)
tree2da50ac10e5f131eccad2fedfbf77742c078ae05 /bin/g-i-installation.sh
parent610098b260ea448af23f9a5fd8b31ae422a6c7d8 (diff)
downloadjenkins.debian.net-28aad1febdd67f72a2655a58348e7f768574da4f.tar.xz
use sparse logical volumes for g-i
These are snapshots of the zero target and thus automatically zeroed, so we do not have to overwrite them avoiding the IO load altogether.
Diffstat (limited to 'bin/g-i-installation.sh')
-rwxr-xr-xbin/g-i-installation.sh13
1 files changed, 2 insertions, 11 deletions
diff --git a/bin/g-i-installation.sh b/bin/g-i-installation.sh
index eace45b3..76078ba4 100755
--- a/bin/g-i-installation.sh
+++ b/bin/g-i-installation.sh
@@ -184,17 +184,8 @@ show_preseed() {
bootstrap_system() {
cd $WORKSPACE
echo "Creating throw-away logical volume with ${DISKSIZE_IN_GB} GiB now."
- sudo lvcreate -L${DISKSIZE_IN_GB}G -n $NAME $VG
- # FIXME: the following will become unneeded / simpler once wheezy is not tested anymore
- RELEASE="$(echo $NAME | cut -d "_" -f2)"
- if [ "$RELEASE" != "jessie" ] ; then
- echo "Workaround to remove swap signature from previous installs, see #757818"
- bs=8192
- let count="1024*1024*1024*${DISKSIZE_IN_GB}/$bs"
- time sudo dd if=/dev/zero of=$LV bs=$bs count=$count || true
- else
- echo "Release $RELEASE detected, where #757818 should be fixed, thus not applying workaround..."
- fi
+ # FIXME: the --virtualsize option will not be needed once wheezy is not tested anymore
+ sudo lvcreate --virtualsize ${DISKSIZE_IN_GB}G -L${DISKSIZE_IN_GB}G -n $NAME $VG
echo "Creating raw disk image with ${DISKSIZE_IN_GB} GiB now."
sudo qemu-img create -f raw $LV ${DISKSIZE_IN_GB}G
echo "Doing g-i installation test for $NAME now."